<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Services.Store

Windows Runtime (WinRT) APIs for for the `Windows.Services.Store` namespace.

This package provides the `winrt.windows.services.store` module.
